@@ -4,7 +4,10 @@ from threading import Lock
 from functools import partial
 from collections import namedtuple
 
-from more_executors._impl.common import copy_future_exception
+from more_executors._impl.common import (
+    copy_future_exception,
+    try_set_result,
+)
 from .base import f_return, chain_cancel, weak_callback
 from .check import ensure_futures
 from ..metrics import track_future
@@ -45,10 +48,14 @@ class Zipper(object):
     def handle_done(self, index, f):
         set_result = False
         set_exception = False
+        cancel = False
 
         with self.lock:
             if self.done:
                 pass
+            elif f.cancelled():
+                self.done = True
+                cancel = True
             elif f.exception():
                 self.done = True
                 set_exception = True
@@ -60,8 +67,10 @@ class Zipper(object):
                     self.done = True
                     set_result = True
 
+        if cancel:
+            self.out.cancel()
         if set_result:
-            self.out.set_result(maketuple(self.fs))
+            try_set_result(self.out, maketuple(self.fs))
         if set_exception:
             copy_future_exception(f, self.out)
 
@@ -81,8 +90,8 @@ def f_zip(*fs):
             A future holding the returned values of all input futures as a tuple.
             The returned tuple has the same length and order as the input futures.
 
-            Alternatively, a future raising an exception, if any input futures raised
-            an exception.
+            Alternatively, a future raising an exception or a cancelled future,
+            if any input futures raised an exception or was cancelled.
 
     .. note::
         This function is tested with up to 100,000 input futures.
